==> ideas-0.0.35-py3-none-any.whl: ideas/session.py <==
"""A file containing a single class meant to keep track of various
configuration choice during a single run/session."""


class State:
    def __init__(self):
        self.console_name = "Ideas Console"
        self.show_original = False
        self.current_file = ""
        self.active_console = False
        self.original = ""
        self._show_changes = False
        try:
            self.in_ipython = get_ipython()  # noqa
        except NameError:
            self.in_ipython = False

    @property
    def show_changes(self):
        return self._show_changes

    @show_changes.setter
    def show_changes(self, value):
        if self.in_ipython:
            print("Showing source changes is not implemented for IPython")
            return
        self._show_changes = value

    def print_original(self, source, header="Original"):
        self.original = source
        if self.active_console:
            return
        if not self.show_original:
            return
        print(f"==========={header}============")
        print(source)
        print("-----------------------------")

    def print_transformed(self, source, header="Transformed"):
        if not self.show_changes:
            return
        if source == self.original:
            return

        lines = source.split("\n")
        if len(lines) == 1:
            print(f"new: {lines[0]}")
            return
        if self.active_console:
            for line in lines:
                print(f"new: {line}")
        else:
            print(f"==========={header}============")
            print(source)
            print("-----------------------------")


config = State()

==> ideas-0.0.39-py3-none-any.whl: ideas/session.py <==
"""A file containing a single class meant to keep track of various
configuration choice during a single run/session."""


class State:
    """Keeps track of various configuration parameters"""

    def __init__(self):
        self.console_name = "Ideas Console"
        self.show_original = False
        self.current_file = ""
        self.active_console = False
        self.original = ""
        self.verbose_finder = False
        self.show_changes = False

    def print_original(self, source, header="Original"):
        """Depending on configuration, can print the original source
        code of a module that was imported."""
        self.original = source
        if self.active_console:
            return
        if not self.show_original:
            return
        print(f"==========={header}============")
        print(source)
        print("-----------------------------")

    def print_transformed(self, source, header="Transformed"):
        """Depending on the configuration, can print the transformed
        output if it differs from the original source.
        """
        if not self.show_changes:
            return
        if source == self.original:
            return

        lines = source.split("\n")
        if len(lines) == 1:
            print(f"new: {lines[0]}")
            return
        if self.active_console:
            for line in lines:
                print(f"new: {line}")
        else:
            print(f"==========={header}============")
            print(source)
            print("-----------------------------")


config = State()
